==> org-lsst-sal-camera-2.2.7-sources.jar: org/lsst/sal/camera/telemetry/Quadbox_PDU_5VTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Quadbox_PDU_5VTelemetry extends CameraTelemetry {
  private final double otm_0_A_V;

  private final double otm_0_A_I;

  private final double otm_0_B_V;

  private final double otm_0_B_I;

  private final double otm_1_A_V;

  private final double otm_1_A_I;

  private final double otm_1_B_V;

  private final double otm_1_B_I;

  private final double otm_2_A_V;

  private final double otm_2_A_I;

  private final double otm_2_B_V;

  private final double otm_2_B_I;

  private final double otm_3_A_V;

  private final double otm_3_A_I;

  private final double otm_3_B_V;

  private final double otm_3_B_I;

  private final double otm_4_A_V;

  private final double otm_4_A_I;

  private final double otm_4_B_V;

  private final double otm_4_B_I;

  private final double otm_5_A_V;

  private final double otm_5_A_I;

  private final double otm_5_B_V;

  private final double otm_5_B_I;

  public Quadbox_PDU_5VTelemetry(double otm_0_A_V, double otm_0_A_I, double otm_0_B_V,
      double otm_0_B_I, double otm_1_A_V, double otm_1_A_I, double otm_1_B_V, double otm_1_B_I,
      double otm_2_A_V, double otm_2_A_I, double otm_2_B_V, double otm_2_B_I, double otm_3_A_V,
      double otm_3_A_I, double otm_3_B_V, double otm_3_B_I, double otm_4_A_V, double otm_4_A_I,
      double otm_4_B_V, double otm_4_B_I, double otm_5_A_V, double otm_5_A_I, double otm_5_B_V,
      double otm_5_B_I) {
    this.otm_0_A_V = otm_0_A_V;
    this.otm_0_A_I = otm_0_A_I;
    this.otm_0_B_V = otm_0_B_V;
    this.otm_0_B_I = otm_0_B_I;
    this.otm_1_A_V = otm_1_A_V;
    this.otm_1_A_I = otm_1_A_I;
    this.otm_1_B_V = otm_1_B_V;
    this.otm_1_B_I = otm_1_B_I;
    this.otm_2_A_V = otm_2_A_V;
    this.otm_2_A_I = otm_2_A_I;
    this.otm_2_B_V = otm_2_B_V;
    this.otm_2_B_I = otm_2_B_I;
    this.otm_3_A_V = otm_3_A_V;
    this.otm_3_A_I = otm_3_A_I;
    this.otm_3_B_V = otm_3_B_V;
    this.otm_3_B_I = otm_3_B_I;
    this.otm_4_A_V = otm_4_A_V;
    this.otm_4_A_I = otm_4_A_I;
    this.otm_4_B_V = otm_4_B_V;
    this.otm_4_B_I = otm_4_B_I;
    this.otm_5_A_V = otm_5_A_V;
    this.otm_5_A_I = otm_5_A_I;
    this.otm_5_B_V = otm_5_B_V;
    this.otm_5_B_I = otm_5_B_I;
  }

  public double getOtm_0_A_V() {
    return otm_0_A_V;
  }

  public double getOtm_0_A_I() {
    return otm_0_A_I;
  }

  public double getOtm_0_B_V() {
    return otm_0_B_V;
  }

  public double getOtm_0_B_I() {
    return otm_0_B_I;
  }

  public double getOtm_1_A_V() {
    return otm_1_A_V;
  }

  public double getOtm_1_A_I() {
    return otm_1_A_I;
  }

  public double getOtm_1_B_V() {
    return otm_1_B_V;
  }

  public double getOtm_1_B_I() {
    return otm_1_B_I;
  }

  public double getOtm_2_A_V() {
    return otm_2_A_V;
  }

  public double getOtm_2_A_I() {
    return otm_2_A_I;
  }

  public double getOtm_2_B_V() {
    return otm_2_B_V;
  }

  public double getOtm_2_B_I() {
    return otm_2_B_I;
  }

  public double getOtm_3_A_V() {
    return otm_3_A_V;
  }

  public double getOtm_3_A_I() {
    return otm_3_A_I;
  }

  public double getOtm_3_B_V() {
    return otm_3_B_V;
  }

  public double getOtm_3_B_I() {
    return otm_3_B_I;
  }

  public double getOtm_4_A_V() {
    return otm_4_A_V;
  }

  public double getOtm_4_A_I() {
    return otm_4_A_I;
  }

  public double getOtm_4_B_V() {
    return otm_4_B_V;
  }

  public double getOtm_4_B_I() {
    return otm_4_B_I;
  }

  public double getOtm_5_A_V() {
    return otm_5_A_V;
  }

  public double getOtm_5_A_I() {
    return otm_5_A_I;
  }

  public double getOtm_5_B_V() {
    return otm_5_B_V;
  }

  public double getOtm_5_B_I() {
    return otm_5_B_I;
  }

  @Override
  public String toString() {
    return "Quadbox_PDU_5VTelemetry{" + "otm_0_A_V=" + otm_0_A_V +", otm_0_A_I=" + otm_0_A_I +
        ", otm_0_B_V=" + otm_0_B_V +", otm_0_B_I=" + otm_0_B_I +", otm_1_A_V=" + otm_1_A_V +
        ", otm_1_A_I=" + otm_1_A_I +", otm_1_B_V=" + otm_1_B_V +", otm_1_B_I=" + otm_1_B_I +
        ", otm_2_A_V=" + otm_2_A_V +", otm_2_A_I=" + otm_2_A_I +", otm_2_B_V=" + otm_2_B_V +
        ", otm_2_B_I=" + otm_2_B_I +", otm_3_A_V=" + otm_3_A_V +", otm_3_A_I=" + otm_3_A_I +
        ", otm_3_B_V=" + otm_3_B_V +", otm_3_B_I=" + otm_3_B_I +", otm_4_A_V=" + otm_4_A_V +
        ", otm_4_A_I=" + otm_4_A_I +", otm_4_B_V=" + otm_4_B_V +", otm_4_B_I=" + otm_4_B_I +
        ", otm_5_A_V=" + otm_5_A_V +", otm_5_A_I=" + otm_5_A_I +", otm_5_B_V=" + otm_5_B_V +
        ", otm_5_B_I=" + otm_5_B_I +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private double otm_0_A_V;

    private double otm_0_A_I;

    private double otm_0_B_V;

    private double otm_0_B_I;

    private double otm_1_A_V;

    private double otm_1_A_I;

    private double otm_1_B_V;

    private double otm_1_B_I;

    private double otm_2_A_V;

    private double otm_2_A_I;

    private double otm_2_B_V;

    private double otm_2_B_I;

    private double otm_3_A_V;

    private double otm_3_A_I;

    private double otm_3_B_V;

    private double otm_3_B_I;

    private double otm_4_A_V;

    private double otm_4_A_I;

    private double otm_4_B_V;

    private double otm_4_B_I;

    private double otm_5_A_V;

    private double otm_5_A_I;

    private double otm_5_B_V;

    private double otm_5_B_I;

    private Builder() {
    }

    public Builder otm_0_A_V(double otm_0_A_V) {
      this.otm_0_A_V = otm_0_A_V;
      return this;
    }

    public Builder otm_0_A_I(double otm_0_A_I) {
      this.otm_0_A_I = otm_0_A_I;
      return this;
    }

    public Builder otm_0_B_V(double otm_0_B_V) {
      this.otm_0_B_V = otm_0_B_V;
      return this;
    }

    public Builder otm_0_B_I(double otm_0_B_I) {
      this.otm_0_B_I = otm_0_B_I;
      return this;
    }

    public Builder otm_1_A_V(double otm_1_A_V) {
      this.otm_1_A_V = otm_1_A_V;
      return this;
    }

    public Builder otm_1_A_I(double otm_1_A_I) {
      this.otm_1_A_I = otm_1_A_I;
      return this;
    }

    public Builder otm_1_B_V(double otm_1_B_V) {
      this.otm_1_B_V = otm_1_B_V;
      return this;
    }

    public Builder otm_1_B_I(double otm_1_B_I) {
      this.otm_1_B_I = otm_1_B_I;
      return this;
    }

    public Builder otm_2_A_V(double otm_2_A_V) {
      this.otm_2_A_V = otm_2_A_V;
      return this;
    }

    public Builder otm_2_A_I(double otm_2_A_I) {
      this.otm_2_A_I = otm_2_A_I;
      return this;
    }

    public Builder otm_2_B_V(double otm_2_B_V) {
      this.otm_2_B_V = otm_2_B_V;
      return this;
    }

    public Builder otm_2_B_I(double otm_2_B_I) {
      this.otm_2_B_I = otm_2_B_I;
      return this;
    }

    public Builder otm_3_A_V(double otm_3_A_V) {
      this.otm_3_A_V = otm_3_A_V;
      return this;
    }

    public Builder otm_3_A_I(double otm_3_A_I) {
      this.otm_3_A_I = otm_3_A_I;
      return this;
    }

    public Builder otm_3_B_V(double otm_3_B_V) {
      this.otm_3_B_V = otm_3_B_V;
      return this;
    }

    public Builder otm_3_B_I(double otm_3_B_I) {
      this.otm_3_B_I = otm_3_B_I;
      return this;
    }

    public Builder otm_4_A_V(double otm_4_A_V) {
      this.otm_4_A_V = otm_4_A_V;
      return this;
    }

    public Builder otm_4_A_I(double otm_4_A_I) {
      this.otm_4_A_I = otm_4_A_I;
      return this;
    }

    public Builder otm_4_B_V(double otm_4_B_V) {
      this.otm_4_B_V = otm_4_B_V;
      return this;
    }

    public Builder otm_4_B_I(double otm_4_B_I) {
      this.otm_4_B_I = otm_4_B_I;
      return this;
    }

    public Builder otm_5_A_V(double otm_5_A_V) {
      this.otm_5_A_V = otm_5_A_V;
      return this;
    }

    public Builder otm_5_A_I(double otm_5_A_I) {
      this.otm_5_A_I = otm_5_A_I;
      return this;
    }

    public Builder otm_5_B_V(double otm_5_B_V) {
      this.otm_5_B_V = otm_5_B_V;
      return this;
    }

    public Builder otm_5_B_I(double otm_5_B_I) {
      this.otm_5_B_I = otm_5_B_I;
      return this;
    }

    public Quadbox_PDU_5VTelemetry build() {
      return new Quadbox_PDU_5VTelemetry(otm_0_A_V, otm_0_A_I, otm_0_B_V, otm_0_B_I, otm_1_A_V, otm_1_A_I, otm_1_B_V, otm_1_B_I, otm_2_A_V, otm_2_A_I, otm_2_B_V, otm_2_B_I, otm_3_A_V, otm_3_A_I, otm_3_B_V, otm_3_B_I, otm_4_A_V, otm_4_A_I, otm_4_B_V, otm_4_B_I, otm_5_A_V, otm_5_A_I, otm_5_B_V, otm_5_B_I);
    }
  }
}

==> org-lsst-sal-camera-2.5.0-sources.jar: org/lsst/sal/camera/telemetry/Quadbox_PDU_5VTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Quadbox_PDU_5VTelemetry extends CameraTelemetry {
  private final double otm_0_A_I;

  private final double otm_0_A_V;

  private final double otm_0_B_I;

  private final double otm_0_B_V;

  private final double otm_1_A_I;

  private final double otm_1_A_V;

  private final double otm_1_B_I;

  private final double otm_1_B_V;

  private final double otm_2_A_I;

  private final double otm_2_A_V;

  private final double otm_2_B_I;

  private final double otm_2_B_V;

  private final double otm_3_A_I;

  private final double otm_3_A_V;

  private final double otm_3_B_I;

  private final double otm_3_B_V;

  private final double otm_4_A_I;

  private final double otm_4_A_V;

  private final double otm_4_B_I;

  private final double otm_4_B_V;

  private final double otm_5_A_I;

  private final double otm_5_A_V;

  private final double otm_5_B_I;

  private final double otm_5_B_V;

  public Quadbox_PDU_5VTelemetry(double otm_0_A_I, double otm_0_A_V, double otm_0_B_I,
      double otm_0_B_V, double otm_1_A_I, double otm_1_A_V, double otm_1_B_I, double otm_1_B_V,
      double otm_2_A_I, double otm_2_A_V, double otm_2_B_I, double otm_2_B_V, double otm_3_A_I,
      double otm_3_A_V, double otm_3_B_I, double otm_3_B_V, double otm_4_A_I, double otm_4_A_V,
      double otm_4_B_I, double otm_4_B_V, double otm_5_A_I, double otm_5_A_V, double otm_5_B_I,
      double otm_5_B_V) {
    this.otm_0_A_I = otm_0_A_I;
    this.otm_0_A_V = otm_0_A_V;
    this.otm_0_B_I = otm_0_B_I;
    this.otm_0_B_V = otm_0_B_V;
    this.otm_1_A_I = otm_1_A_I;
    this.otm_1_A_V = otm_1_A_V;
    this.otm_1_B_I = otm_1_B_I;
    this.otm_1_B_V = otm_1_B_V;
    this.otm_2_A_I = otm_2_A_I;
    this.otm_2_A_V = otm_2_A_V;
    this.otm_2_B_I = otm_2_B_I;
    this.otm_2_B_V = otm_2_B_V;
    this.otm_3_A_I = otm_3_A_I;
    this.otm_3_A_V = otm_3_A_V;
    this.otm_3_B_I = otm_3_B_I;
    this.otm_3_B_V = otm_3_B_V;
    this.otm_4_A_I = otm_4_A_I;
    this.otm_4_A_V = otm_4_A_V;
    this.otm_4_B_I = otm_4_B_I;
    this.otm_4_B_V = otm_4_B_V;
    this.otm_5_A_I = otm_5_A_I;
    this.otm_5_A_V = otm_5_A_V;
    this.otm_5_B_I = otm_5_B_I;
    this.otm_5_B_V = otm_5_B_V;
  }

  public double getOtm_0_A_I() {
    return otm_0_A_I;
  }

  public double getOtm_0_A_V() {
    return otm_0_A_V;
  }

  public double getOtm_0_B_I() {
    return otm_0_B_I;
  }

  public double getOtm_0_B_V() {
    return otm_0_B_V;
  }

  public double getOtm_1_A_I() {
    return otm_1_A_I;
  }

  public double getOtm_1_A_V() {
    return otm_1_A_V;
  }

  public double getOtm_1_B_I() {
    return otm_1_B_I;
  }

  public double getOtm_1_B_V() {
    return otm_1_B_V;
  }

  public double getOtm_2_A_I() {
    return otm_2_A_I;
  }

  public double getOtm_2_A_V() {
    return otm_2_A_V;
  }

  public double getOtm_2_B_I() {
    return otm_2_B_I;
  }

  public double getOtm_2_B_V() {
    return otm_2_B_V;
  }

  public double getOtm_3_A_I() {
    return otm_3_A_I;
  }

  public double getOtm_3_A_V() {
    return otm_3_A_V;
  }

  public double getOtm_3_B_I() {
    return otm_3_B_I;
  }

  public double getOtm_3_B_V() {
    return otm_3_B_V;
  }

  public double getOtm_4_A_I() {
    return otm_4_A_I;
  }

  public double getOtm_4_A_V() {
    return otm_4_A_V;
  }

  public double getOtm_4_B_I() {
    return otm_4_B_I;
  }

  public double getOtm_4_B_V() {
    return otm_4_B_V;
  }

  public double getOtm_5_A_I() {
    return otm_5_A_I;
  }

  public double getOtm_5_A_V() {
    return otm_5_A_V;
  }

  public double getOtm_5_B_I() {
    return otm_5_B_I;
  }

  public double getOtm_5_B_V() {
    return otm_5_B_V;
  }

  @Override
  public String toString() {
    return "Quadbox_PDU_5VTelemetry{" + "otm_0_A_I=" + otm_0_A_I +", otm_0_A_V=" + otm_0_A_V +
        ", otm_0_B_I=" + otm_0_B_I +", otm_0_B_V=" + otm_0_B_V +", otm_1_A_I=" + otm_1_A_I +
        ", otm_1_A_V=" + otm_1_A_V +", otm_1_B_I=" + otm_1_B_I +", otm_1_B_V=" + otm_1_B_V +
        ", otm_2_A_I=" + otm_2_A_I +", otm_2_A_V=" + otm_2_A_V +", otm_2_B_I=" + otm_2_B_I +
        ", otm_2_B_V=" + otm_2_B_V +", otm_3_A_I=" + otm_3_A_I +", otm_3_A_V=" + otm_3_A_V +
        ", otm_3_B_I=" + otm_3_B_I +", otm_3_B_V=" + otm_3_B_V +", otm_4_A_I=" + otm_4_A_I +
        ", otm_4_A_V=" + otm_4_A_V +", otm_4_B_I=" + otm_4_B_I +", otm_4_B_V=" + otm_4_B_V +
        ", otm_5_A_I=" + otm_5_A_I +", otm_5_A_V=" + otm_5_A_V +", otm_5_B_I=" + otm_5_B_I +
        ", otm_5_B_V=" + otm_5_B_V +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private double otm_0_A_I;

    private double otm_0_A_V;

    private double otm_0_B_I;

    private double otm_0_B_V;

    private double otm_1_A_I;

    private double otm_1_A_V;

    private double otm_1_B_I;

    private double otm_1_B_V;

    private double otm_2_A_I;

    private double otm_2_A_V;

    private double otm_2_B_I;

    private double otm_2_B_V;

    private double otm_3_A_I;

    private double otm_3_A_V;

    private double otm_3_B_I;

    private double otm_3_B_V;

    private double otm_4_A_I;

    private double otm_4_A_V;

    private double otm_4_B_I;

    private double otm_4_B_V;

    private double otm_5_A_I;

    private double otm_5_A_V;

    private double otm_5_B_I;

    private double otm_5_B_V;

    private Builder() {
    }

    public Builder otm_0_A_I(double otm_0_A_I) {
      this.otm_0_A_I = otm_0_A_I;
      return this;
    }

    public Builder otm_0_A_V(double otm_0_A_V) {
      this.otm_0_A_V = otm_0_A_V;
      return this;
    }

    public Builder otm_0_B_I(double otm_0_B_I) {
      this.otm_0_B_I = otm_0_B_I;
      return this;
    }

    public Builder otm_0_B_V(double otm_0_B_V) {
      this.otm_0_B_V = otm_0_B_V;
      return this;
    }

    public Builder otm_1_A_I(double otm_1_A_I) {
      this.otm_1_A_I = otm_1_A_I;
      return this;
    }

    public Builder otm_1_A_V(double otm_1_A_V) {
      this.otm_1_A_V = otm_1_A_V;
      return this;
    }

    public Builder otm_1_B_I(double otm_1_B_I) {
      this.otm_1_B_I = otm_1_B_I;
      return this;
    }

    public Builder otm_1_B_V(double otm_1_B_V) {
      this.otm_1_B_V = otm_1_B_V;
      return this;
    }

    public Builder otm_2_A_I(double otm_2_A_I) {
      this.otm_2_A_I = otm_2_A_I;
      return this;
    }

    public Builder otm_2_A_V(double otm_2_A_V) {
      this.otm_2_A_V = otm_2_A_V;
      return this;
    }

    public Builder otm_2_B_I(double otm_2_B_I) {
      this.otm_2_B_I = otm_2_B_I;
      return this;
    }

    public Builder otm_2_B_V(double otm_2_B_V) {
      this.otm_2_B_V = otm_2_B_V;
      return this;
    }

    public Builder otm_3_A_I(double otm_3_A_I) {
      this.otm_3_A_I = otm_3_A_I;
      return this;
    }

    public Builder otm_3_A_V(double otm_3_A_V) {
      this.otm_3_A_V = otm_3_A_V;
      return this;
    }

    public Builder otm_3_B_I(double otm_3_B_I) {
      this.otm_3_B_I = otm_3_B_I;
      return this;
    }

    public Builder otm_3_B_V(double otm_3_B_V) {
      this.otm_3_B_V = otm_3_B_V;
      return this;
    }

    public Builder otm_4_A_I(double otm_4_A_I) {
      this.otm_4_A_I = otm_4_A_I;
      return this;
    }

    public Builder otm_4_A_V(double otm_4_A_V) {
      this.otm_4_A_V = otm_4_A_V;
      return this;
    }

    public Builder otm_4_B_I(double otm_4_B_I) {
      this.otm_4_B_I = otm_4_B_I;
      return this;
    }

    public Builder otm_4_B_V(double otm_4_B_V) {
      this.otm_4_B_V = otm_4_B_V;
      return this;
    }

    public Builder otm_5_A_I(double otm_5_A_I) {
      this.otm_5_A_I = otm_5_A_I;
      return this;
    }

    public Builder otm_5_A_V(double otm_5_A_V) {
      this.otm_5_A_V = otm_5_A_V;
      return this;
    }

    public Builder otm_5_B_I(double otm_5_B_I) {
      this.otm_5_B_I = otm_5_B_I;
      return this;
    }

    public Builder otm_5_B_V(double otm_5_B_V) {
      this.otm_5_B_V = otm_5_B_V;
      return this;
    }

    public Quadbox_PDU_5VTelemetry build() {
      return new Quadbox_PDU_5VTelemetry(otm_0_A_I, otm_0_A_V, otm_0_B_I, otm_0_B_V, otm_1_A_I, otm_1_A_V, otm_1_B_I, otm_1_B_V, otm_2_A_I, otm_2_A_V, otm_2_B_I, otm_2_B_V, otm_3_A_I, otm_3_A_V, otm_3_B_I, otm_3_B_V, otm_4_A_I, otm_4_A_V, otm_4_B_I, otm_4_B_V, otm_5_A_I, otm_5_A_V, otm_5_B_I, otm_5_B_V);
    }
  }
}
